==> kcdlabel_2.12-KDE3.orig.tar.gz: kcdlabel-2.12-KDE3/kcdlabel/thanksdlg.cpp <==
/***************************************************************************
                          thanksdlg.cpp  -  description
                             -------------------
    begin                : Mon Jul 24 2000
    copyright            : (C) 2000 by Pascal 'PeP' Panneels
    email                : pepouille@skynet.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "thanksdlg.h"
#include "version.h"
#include <kapp.h>
#include <klocale.h>

char * thanks[]= {
				 (char *)"[0,0,255]KCDLabel",
				 (char *)__KCDL_VERSION_2,
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"Pascal Panneels",
				 (char *)"(pepouille@skynet.be)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"I'd like to thank the following people",
				 (char *)"for helping me making this software looking nice :",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]QT/KDE Coding hints and tests",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]my good old chap,",
				 (char *)"[255,255,255]Philippe 'Philoux' Van Hecke",
				 (char *)"[255,255,255](lephiloux@skynet.be)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]KDE 3 Adaptation (sources/project)",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Dag Nygren",
				 (char *)"[255,255,255](dag@newtech.fi)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]RPM Packaging (binary and sources)",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Hio",
				 (char *)"[255,255,255](hio@lombardiacom.it)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Debian Packaging (binary and sources)",
				 (char *)"",
				 (char *)"[255,255,255]Stephen Gran",
				 (char *)"[255,255,255](gashuffer09@comcast.net)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Translations",				
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,0]German translations",
				 (char *)"",
				 (char *)"[255,255,255]my beer-brother",
				 (char *)"[255,255,255]Frank Weis",
				 (char *)"[255,255,255](Frank.Weis@cte.lu)",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,0]Italian translations",
				 (char *)"",
				 (char *)"[255,255,255]Simonini Gianluca",
				 (char *)"[255,255,255](UP32@mail.barilla.it)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Love, support and kisses  ;-)",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]My wife, Isabelle",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Tests, bugs report and support",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Hasso Tepper (hasso@estpak.ee)",
				 (char *)"[255,255,255]Bruce S. Garlock (bruceg@garlockprinting.com)",
				 (char *)"[255,255,255]Dmitry Melamud (d_melamud@tet.com.ua)",
				 (char *)"[255,255,255]George Chan (georgewendy@yahoo.com)",
				 (char *)"[255,255,255]Rither (rither@wanadoo.fr)",
				 (char *)"[255,255,255]Saege (saege@pctc.chemie.uni-erlangen.de)",
				 (char *)"[255,255,255]Steven W. Orr (steveo@world.std.com)",				
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Mirroring at http://www.computerchannel.de",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Garrett Morriss (morriss.garrett@computerchannel.de)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Mirroring at http://www.iamyourhandiman.com",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Lee Johnson  (???@???)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,0]THANKS TO ALL OF YOU !",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"Still there ?  ;-)",
				 (char *)"Ok, here we scroll again !",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 };

ThanksDlg::ThanksDlg(QWidget *parent, const char *name) : QDialog(parent,name,true)
{
	initDialog();
	scrollframe = new QScrollFrame(this);
	scrollframe->setGeometry( 20,10, width()-40, height()-60 );
	scrollframe->setBackgroundColor( darkGray );
	scrollframe->setDefaultColor( black );
	scrollframe->setScrollText( thanks, sizeof(thanks)/sizeof(char *) );
	scrollframe->setInterval(20);
	scrollframe->setDefaultFont(QFont("helvetica",10));
	scrollframe->start();
	setCaption(i18n("Greetings and thanks"))	;
	QObject::connect(QPushButton_1, SIGNAL(clicked()), this, SLOT(accept()) );
}

==> kcdlabel_2.13-KDE3.orig.tar.gz: kcdlabel-2.13-KDE3/kcdlabel/thanksdlg.cpp <==
/***************************************************************************
                          thanksdlg.cpp  -  description
                             -------------------
    begin                : Mon Jul 24 2000
    copyright            : (C) 2000 by Pascal 'PeP' Panneels
    email                : pepouille@skynet.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "thanksdlg.h"
#include "version.h"
#include <kapp.h>
#include <klocale.h>

char * thanks[]= {
				 (char *)"[0,0,255]KCDLabel",
				 (char *)__KCDL_VERSION_2,
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"Pascal Panneels",
				 (char *)"(pepouille@skynet.be)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"I'd like to thank the following people",
				 (char *)"for helping me making this software looking nice :",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]QT/KDE Coding hints and tests",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]my good old chap,",
				 (char *)"[255,255,255]Philippe 'Philoux' Van Hecke",
				 (char *)"[255,255,255](lephiloux@skynet.be)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]KDE 3 Adaptation (sources/project)",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Dag Nygren",
				 (char *)"[255,255,255](dag@newtech.fi)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]RPM Packaging (binary and sources)",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Hio",
				 (char *)"[255,255,255](hio@lombardiacom.it)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Debian Packaging (binary and sources)",
				 (char *)"",
				 (char *)"[255,255,255]Stephen Gran",
				 (char *)"[255,255,255](sgran@debian.org)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Translations",				
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,0]German translations",
				 (char *)"",
				 (char *)"[255,255,255]my beer-brother",
				 (char *)"[255,255,255]Frank Weis",
				 (char *)"[255,255,255](Frank.Weis@cte.lu)",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,0]Italian translations",
				 (char *)"",
				 (char *)"[255,255,255]Simonini Gianluca",
				 (char *)"[255,255,255](UP32@mail.barilla.it)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Love, support and kisses  ;-)",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]My wife, Isabelle",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Tests, bugs report and support",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Hasso Tepper (hasso@estpak.ee)",
				 (char *)"[255,255,255]Bruce S. Garlock (bruceg@garlockprinting.com)",
				 (char *)"[255,255,255]Dmitry Melamud (d_melamud@tet.com.ua)",
				 (char *)"[255,255,255]George Chan (georgewendy@yahoo.com)",
				 (char *)"[255,255,255]Rither (rither@wanadoo.fr)",
				 (char *)"[255,255,255]Saege (saege@pctc.chemie.uni-erlangen.de)",
				 (char *)"[255,255,255]Steven W. Orr (steveo@world.std.com)",				
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Mirroring at http://www.computerchannel.de",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Garrett Morriss (morriss.garrett@computerchannel.de)",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[0,0,255]Mirroring at http://www.iamyourhandiman.com",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,255]Lee Johnson  ( email unknown )",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"[255,255,0]THANKS TO ALL OF YOU !",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"Still there ?  ;-)",
				 (char *)"Ok, here we scroll again !",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 (char *)"",
				 };

ThanksDlg::ThanksDlg(QWidget *parent, const char *name) : QDialog(parent,name,true)
{
	initDialog();
	scrollframe = new QScrollFrame(this);
	scrollframe->setGeometry( 20,10, width()-40, height()-60 );
	scrollframe->setBackgroundColor( darkGray );
	scrollframe->setDefaultColor( black );
	scrollframe->setScrollText( thanks, sizeof(thanks)/sizeof(char *) );
	scrollframe->setInterval(20);
	scrollframe->setDefaultFont(QFont("helvetica",10));
	scrollframe->start();
	setCaption(i18n("Greetings and thanks"))	;
	QObject::connect(QPushButton_1, SIGNAL(clicked()), this, SLOT(accept()) );
}
